@@ -20,6 +20,7 @@ Setup functions for Pepper API work
 import socket
 import sys
 import glob
+import platform
 
 try:
     socket.gethostname()
@@ -27,6 +28,11 @@ except:
     print "Replacing gethostname()"
     socket.gethostname = lambda: 'localhost'
 
+
+# Override platform information.  This isn't too much fun.
+platform.system = lambda: "pnacl"
+platform.release = lambda: "chrome"
+
 from .ppapi_wrapper import NaClInstance
 nacl_instance = NaClInstance()
 nacl_instance.pylab()
